@@ -53,6 +53,7 @@ from nuitka.Options import (
     isOnefileTempDirMode,
     isStandaloneMode,
     shallCreateAppBundle,
+    shallMakeDll,
     shallMakeModule,
     shallShowExecutedCommands,
 )
@@ -82,8 +83,12 @@ from nuitka.utils.Execution import (
 from nuitka.utils.FileOperations import (
     changeFilenameExtension,
     getFileContents,
+    getReportSourceReference,
+)
+from nuitka.utils.Importing import (
+    getExtensionModuleSuffix,
+    isBuiltinModuleName,
 )
-from nuitka.utils.Importing import getSharedLibrarySuffix, isBuiltinModuleName
 from nuitka.utils.ModuleNames import (
     ModuleName,
     makeTriggerModuleName,
@@ -157,6 +162,7 @@ def _getEvaluationContext():
             "onefile": isOnefileMode(),
             "onefile_cached": not isOnefileTempDirMode(),
             "module_mode": shallMakeModule(),
+            "dll_mode": shallMakeDll(),
             "deployment": isDeploymentMode(),
             # Version information
             "company": getCompanyName(),
@@ -229,10 +235,12 @@ def _getEvaluationContext():
         _context_dict["python3_or_higher"] = python_version >= 0x300
 
         if not isNuitkaPython():
-            _context_dict["extension_std_suffix"] = getSharedLibrarySuffix(
+            _context_dict["extension_std_suffix"] = getExtensionModuleSuffix(
                 preferred=True
             )
-            _context_dict["extension_suffix"] = getSharedLibrarySuffix(preferred=False)
+            _context_dict["extension_suffix"] = getExtensionModuleSuffix(
+                preferred=False
+            )
 
     return _context_dict
 
@@ -346,10 +354,17 @@ def _hasModule(module_name):
     return finding != "not-found"
 
 
-def _getPackageData(package_name, resource):
+def _getPackageData(package_name, resource, default=None):
+
     from nuitka.utils.PackageResources import getPackageData
 
-    return getPackageData(package_name=ModuleName(package_name), resource=resource)
+    try:
+        return getPackageData(package_name=ModuleName(package_name), resource=resource)
+    except FileNotFoundError:
+        if default is not None:
+            return default
+
+        raise
 
 
 def _iterate_module_names(package_name):
@@ -374,6 +389,37 @@ def _isPluginActive(plugin_name):
     return plugin_name in getUserActivatedPluginNames()
 
 
+# Workaround for "ast.literal_eval" not working properly for set literals
+# before Python3.9, spell-checker: ignore elts
+if python_version >= 0x390:
+    _literal_eval = ast.literal_eval
+else:
+
+    class RewriteName(ast.NodeTransformer):
+        @staticmethod
+        def visit_Call(node):
+            if node.func.id == "set" and node.args == node.keywords == []:
+                if python_version >= 0x380:
+                    return ast.Constant(
+                        value=set(),
+                    )
+                else:
+                    # TODO: For Python2 it doesn't work to parse sets literals,
+                    # if we ever find we need them, we need to workaround that
+                    # by maybe implementing it entirely.
+                    return ast.Set(
+                        # spell-checker: ignore elts
+                        elts=[],
+                    )
+
+    def _literal_eval(value):
+        if "set()" in value:
+            value = ast.parse(value, mode="eval")
+            RewriteName().visit(value)
+
+        return ast.literal_eval(value)
+
+
 class NuitkaPluginBase(getMetaClassBase("Plugin", require_slots=False)):
     """Nuitka base class for all plugins.
 
@@ -1185,6 +1231,11 @@ Unwanted import of '%(unwanted)s' that %(problem)s '%(binding_name)s' encountere
             )
         )
 
+    @staticmethod
+    def getReportSourceReference(source_ref):
+        """Format a source reference suitable for user output."""
+        return getReportSourceReference(source_ref)
+
     def getExtraCodeFiles(self):
         """Add extra code files to the compilation.
 
@@ -1273,6 +1324,8 @@ Unwanted import of '%(unwanted)s' that %(problem)s '%(binding_name)s' encountere
     _runtime_information_cache = {}
 
     def queryRuntimeInformationMultiple(self, info_name, setup_codes, values):
+        # Rather complicated error handling, pylint: disable=too-many-branches
+
         info_name = self.plugin_name + "_" + info_name
         info_name = info_name.replace("-", "_").replace(".", "_")
 
@@ -1364,9 +1417,15 @@ except Exception as e:
 
         NamedtupleResultClass = makeNamedtupleClass(info_name, keys)
 
-        self._runtime_information_cache[info_name] = NamedtupleResultClass(
-            *(ast.literal_eval(value) for value in feedback)
-        )
+        try:
+            self._runtime_information_cache[info_name] = NamedtupleResultClass(
+                *(_literal_eval(value) for value in feedback)
+            )
+        except ValueError:
+            self.sysexit(
+                "Error, non-constant values in output retrieving %r information."
+                % info_name
+            )
 
         return self._runtime_information_cache[info_name]
 
